@@ -29,6 +29,7 @@ def add_cors(new_app):
 
 def add_tasks_and_process_time_middleware(new_app):
     from magicapi.Models.task_executor import save_tasks
+    from magicapi.Models.NotFound import save_not_found_from_request
 
     @new_app.middleware("http")
     async def add_process_time_and_tasks(request: Request, call_next):
@@ -37,9 +38,9 @@ def add_tasks_and_process_time_middleware(new_app):
         g.app = new_app
         print("url path", request.url.path, "***url", request.url)
         response = await call_next(request)
-        # response.headers["X-Tasks-Time"] = str(g.save_tasks())  # queue tasks
+        if response.status_code == 404 and g.settings.save_calls:
+            await save_not_found_from_request(request)
         response.headers["X-Tasks-Time"] = str(save_tasks())  # queue tasks
-
         response.headers["X-Process-Time"] = str(time.time() - start_time)
         return response
 
@@ -65,8 +66,9 @@ def add_background_tasks():
     from magicapi.Decorators.background_tasks import run_in_background
 
 
-def make_magic_router(app: FastAPI):
+def make_magic_router():
     from magicapi.RouteClasses import MagicCallLogger
+
     magic_router = APIRouter(route_class=MagicCallLogger)
     g.magic_router = magic_router
 
@@ -75,8 +77,12 @@ def add_magic_routers():
     g.app.include_router(g.magic_router)
 
 
+def set_settings(settings=MagicSettings()):
+    g.settings = settings
+
+
 def create_app(config_settings=MagicSettings()):
-    g.settings = config_settings
+    set_settings(config_settings)
     print("creating_app", datetime.datetime.now())
     new_app = FastAPI(
         title=config_settings.app_name,
@@ -84,14 +90,14 @@ def create_app(config_settings=MagicSettings()):
         root_path="" if config_settings.local else f"/{config_settings.stage}",
     )
 
-    add_addons(new_app)
     g.app = new_app
     add_background_tasks()
-    make_magic_router(g.app)
+    make_magic_router()
+    add_addons(g.app)
 
     config_firestore(g.settings.service_account_name)
 
-    return new_app
+    return g.app
 
 
 def create_handler(app):
